@@ -58,7 +58,8 @@ def list_jobs(
         >>> from snowflake.ml.jobs import list_jobs
         >>> list_jobs(limit=5)
     """
-    session = session or get_active_session()
+
+    session = _ensure_session(session)
     try:
         df = _get_job_history_spcs(
             session,
@@ -162,7 +163,7 @@ def _get_job_history_spcs(
 @telemetry.send_api_usage_telemetry(project=_PROJECT)
 def get_job(job_id: str, session: Optional[snowpark.Session] = None) -> jb.MLJob[Any]:
     """Retrieve a job service from the backend."""
-    session = session or get_active_session()
+    session = _ensure_session(session)
     try:
         database, schema, job_name = identifier.parse_schema_level_object_identifier(job_id)
         database = identifier.resolve_identifier(cast(str, database or session.get_current_database()))
@@ -231,6 +232,7 @@ def submit_file(
             enable_metrics (bool): Whether to enable metrics publishing for the job.
             query_warehouse (str): The query warehouse to use. Defaults to session warehouse.
             spec_overrides (dict): A dictionary of overrides for the service spec.
+            imports (list[Union[tuple[str, str], tuple[str]]]): A list of additional payloads used in the job.
 
     Returns:
         An object representing the submitted job.
@@ -285,6 +287,7 @@ def submit_directory(
             enable_metrics (bool): Whether to enable metrics publishing for the job.
             query_warehouse (str): The query warehouse to use. Defaults to session warehouse.
             spec_overrides (dict): A dictionary of overrides for the service spec.
+            imports (list[Union[tuple[str, str], tuple[str]]]): A list of additional payloads used in the job.
 
     Returns:
         An object representing the submitted job.
@@ -340,6 +343,7 @@ def submit_from_stage(
             enable_metrics (bool): Whether to enable metrics publishing for the job.
             query_warehouse (str): The query warehouse to use. Defaults to session warehouse.
             spec_overrides (dict): A dictionary of overrides for the service spec.
+            imports (list[Union[tuple[str, str], tuple[str]]]): A list of additional payloads used in the job.
 
     Returns:
         An object representing the submitted job.
@@ -403,6 +407,8 @@ def _submit_job(
         "num_instances",  # deprecated
         "target_instances",
         "min_instances",
+        "enable_metrics",
+        "query_warehouse",
     ],
 )
 def _submit_job(
@@ -434,8 +440,10 @@ def _submit_job(
 
     Raises:
         ValueError: If database or schema value(s) are invalid
+        RuntimeError: If schema is not specified in session context or job submission
+        snowpark.exceptions.SnowparkSQLException: if failed to upload payload
     """
-    session = session or get_active_session()
+    session = _ensure_session(session)
 
     # Check for deprecated args
     if "num_instances" in kwargs:
@@ -444,6 +452,13 @@ def _submit_job(
         )
         target_instances = max(target_instances, kwargs.pop("num_instances"))
 
+    imports = None
+    if "additional_payloads" in kwargs:
+        logger.warning(
+            "'additional_payloads' is deprecated and will be removed in a future release. Use 'imports' instead."
+        )
+        imports = kwargs.pop("additional_payloads")
+
     # Use kwargs for less common optional parameters
     database = kwargs.pop("database", None)
     schema = kwargs.pop("schema", None)
@@ -454,10 +469,7 @@ def _submit_job(
     spec_overrides = kwargs.pop("spec_overrides", None)
     enable_metrics = kwargs.pop("enable_metrics", True)
     query_warehouse = kwargs.pop("query_warehouse", session.get_current_warehouse())
-    additional_payloads = kwargs.pop("additional_payloads", None)
-
-    if additional_payloads:
-        logger.warning("'additional_payloads' is in private preview since 1.9.1. Do not use it in production.")
+    imports = kwargs.pop("imports", None) or imports
 
     # Warn if there are unknown kwargs
     if kwargs:
@@ -486,10 +498,33 @@ def _submit_job(
     stage_name = f"@{'.'.join(filter(None, stage_path_parts[:3]))}"
     stage_path = pathlib.PurePosixPath(f"{stage_name}{stage_path_parts[-1].rstrip('/')}/{job_name}")
 
-    # Upload payload
-    uploaded_payload = payload_utils.JobPayload(
-        source, entrypoint=entrypoint, pip_requirements=pip_requirements, additional_payloads=additional_payloads
-    ).upload(session, stage_path)
+    try:
+        # Upload payload
+        uploaded_payload = payload_utils.JobPayload(
+            source, entrypoint=entrypoint, pip_requirements=pip_requirements, additional_payloads=imports
+        ).upload(session, stage_path)
+    except snowpark.exceptions.SnowparkSQLException as e:
+        if e.sql_error_code == 90106:
+            raise RuntimeError(
+                "Please specify a schema, either in the session context or as a parameter in the job submission"
+            )
+        raise
+
+    # FIXME: Temporary patches, remove this after v1 is deprecated
+    if target_instances > 1:
+        default_spec_overrides = {
+            "spec": {
+                "endpoints": [
+                    {"name": "ray-dashboard-endpoint", "port": 12003, "protocol": "TCP"},
+                ]
+            },
+        }
+        if spec_overrides:
+            spec_overrides = spec_utils.merge_patch(
+                default_spec_overrides, spec_overrides, display_name="spec_overrides"
+            )
+        else:
+            spec_overrides = default_spec_overrides
 
     if feature_flags.FeatureFlags.USE_SUBMIT_JOB_V2.is_enabled():
         # Add default env vars (extracted from spec_utils.generate_service_spec)
@@ -651,3 +686,17 @@ def _do_submit_job_v2(
     actual_job_id = query_helper.run_query(session, query_template, params=params)[0][0]
 
     return get_job(actual_job_id, session=session)
+
+
+def _ensure_session(session: Optional[snowpark.Session]) -> snowpark.Session:
+    try:
+        session = session or get_active_session()
+    except snowpark.exceptions.SnowparkSessionException as e:
+        if "More than one active session" in e.message:
+            raise RuntimeError(
+                "More than one active session is found. Please specify the session explicitly as a parameter"
+            ) from None
+        if "No default Session is found" in e.message:
+            raise RuntimeError("No active session is found. Please create a session") from None
+        raise
+    return session
